==> coupon-facade-1.0.3-20190722.020245-37-sources.jar: com/bizvane/couponfacade/models/vo/CouponOfflineUseRequestVO.java <==
package com.bizvane.couponfacade.models.vo;

import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.math.BigDecimal;

public class CouponOfflineUseRequestVO implements Serializable {

  /**
   * 
   */
  private static final long serialVersionUID = 1L;

  @io.swagger.annotations.ApiModelProperty(value = "券号", name = "couponCode", required = false,example = "")
  private String couponCode;

  @io.swagger.annotations.ApiModelProperty(value = "描述", name = "description", required = false,example = "")
  private String description;

  @io.swagger.annotations.ApiModelProperty(value = "业务单号", name = "businessCode", required = false,example = "")
  private String businessCode;

  @io.swagger.annotations.ApiModelProperty(value = "品牌id", name = "sysBrandId", required = false,example = "")
  private Long sysBrandId;

  @io.swagger.annotations.ApiModelProperty(value = "使用时间", name = "useTime", required = false,example = "")
  private String useTime;

  @io.swagger.annotations.ApiModelProperty(value = "所属企业id", name = "sysCompanyId", required = false, example = "")
  private Long sysCompanyId;

  @io.swagger.annotations.ApiModelProperty(value = "是否会员", name = "isMember", required = false,example = "")
  private Integer isMember;

  @io.swagger.annotations.ApiModelProperty(value = "店铺编码", name = "useStoreCode", required = false,example = "")
  private String useStoreCode;

  @io.swagger.annotations.ApiModelProperty(value = "店铺id", name = "useStoreId", required = false,example = "")
  private Long useStoreId;

  @ApiModelProperty(value = "核销金额", name = "profitMoney", required = false,example = "")
  private BigDecimal profitMoney;

  @ApiModelProperty(value = "优惠金额", name = "discountMoney", required = false,example = "")
  private BigDecimal discountMoney;

  @ApiModelProperty(value = "核销来源", name = "useFrom", required = false,example = "")
  private Byte useFrom;

  @io.swagger.annotations.ApiModelProperty(value = "员工编号", name = "staffCode", required = false,example = "")
  private String staffCode;
  
  
  @io.swagger.annotations.ApiModelProperty(value = "核销门店code", name = "核销门店code", required = false,example = "")
  private String verifyedStoreCode;
  
  @io.swagger.annotations.ApiModelProperty(value = "核销人(导购code)", name = "导购code", required = false,example = "")
  private String verifyedUser;
  

	public String getVerifyedUser() {
		return verifyedUser;
	}

	public void setVerifyedUser(String verifyedUser) {
		this.verifyedUser = verifyedUser;
	}

	public String getVerifyedStoreCode() {
		return verifyedStoreCode;
	}

	public void setVerifyedStoreCode(String verifyedStoreCode) {
		this.verifyedStoreCode = verifyedStoreCode;
	}

  
  
  public Long getSysCompanyId() {
	return sysCompanyId;
}

public void setSysCompanyId(Long sysCompanyId) {
	this.sysCompanyId = sysCompanyId;
}

public String getStaffCode() {
    return staffCode;
  }

  public void setStaffCode(String staffCode) {
    this.staffCode = staffCode;
  }


  public Byte getUseFrom() {
    return useFrom;
  }

  public void setUseFrom(Byte useFrom) {
    this.useFrom = useFrom;
  }

  public String getCouponCode() {
    return couponCode;
  }

  public void setCouponCode(String couponCode) {
    this.couponCode = couponCode;
  }

  public String getDescription() {
    return description;
  }

  public void setDescription(String description) {
    this.description = description;
  }

  public String getBusinessCode() {
    return businessCode;
  }

  public void setBusinessCode(String businessCode) {
    this.businessCode = businessCode;
  }

  public Long getSysBrandId() {
    return sysBrandId;
  }

  public void setSysBrandId(Long sysBrandId) {
    this.sysBrandId = sysBrandId;
  }

  public String getUseStoreCode() {
    return useStoreCode;
  }

  public void setUseStoreCode(String useStoreCode) {
    this.useStoreCode = useStoreCode;
  }

  public Long getUseStoreId() {
    return useStoreId;
  }

  public void setUseStoreId(Long useStoreId) {
    this.useStoreId = useStoreId;
  }

  public Integer getIsMember() {
    return isMember;
  }

  public void setIsMember(Integer isMember) {
    this.isMember = isMember;
  }

  public BigDecimal getProfitMoney() {
    return profitMoney;
  }

  public void setProfitMoney(BigDecimal profitMoney) {
    this.profitMoney = profitMoney;
  }

  public BigDecimal getDiscountMoney() {
    return discountMoney;
  }

  public void setDiscountMoney(BigDecimal discountMoney) {
    this.discountMoney = discountMoney;
  }

  public String getUseTime() {
    return useTime;
  }

  public void setUseTime(String useTime) {
    this.useTime = useTime;
  }
}

==> coupon-facade-2.0.0-20191125.082728-32-sources.jar: com/bizvane/couponfacade/models/vo/CouponOfflineUseRequestVO.java <==
package com.bizvane.couponfacade.models.vo;

import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.math.BigDecimal;

public class CouponOfflineUseRequestVO implements Serializable {

  /**
   * 
   */
  private static final long serialVersionUID = 1L;

  @io.swagger.annotations.ApiModelProperty(value = "券号", name = "couponCode", required = false,example = "")
  private String couponCode;

  @io.swagger.annotations.ApiModelProperty(value = "描述", name = "description", required = false,example = "")
  private String description;

  @io.swagger.annotations.ApiModelProperty(value = "业务单号", name = "businessCode", required = false,example = "")
  private String businessCode;

  @io.swagger.annotations.ApiModelProperty(value = "品牌id", name = "sysBrandId", required = false,example = "")
  private Long sysBrandId;

  @io.swagger.annotations.ApiModelProperty(value = "使用时间", name = "useTime", required = false,example = "")
  private String useTime;

  @io.swagger.annotations.ApiModelProperty(value = "所属企业id", name = "sysCompanyId", required = false, example = "")
  private Long sysCompanyId;

  @io.swagger.annotations.ApiModelProperty(value = "是否会员", name = "isMember", required = false,example = "")
  private Integer isMember;

  @io.swagger.annotations.ApiModelProperty(value = "店铺编码", name = "useStoreCode", required = false,example = "")
  private String useStoreCode;

  @io.swagger.annotations.ApiModelProperty(value = "店铺id", name = "useStoreId", required = false,example = "")
  private String useStoreId;

  @ApiModelProperty(value = "核销金额", name = "profitMoney", required = false,example = "")
  private BigDecimal profitMoney;

  @ApiModelProperty(value = "优惠金额", name = "discountMoney", required = false,example = "")
  private BigDecimal discountMoney;

  @ApiModelProperty(value = "核销来源", name = "useFrom", required = false,example = "")
  private Byte useFrom;

  @io.swagger.annotations.ApiModelProperty(value = "员工编号", name = "staffCode", required = false,example = "")
  private String staffCode;
  
  
  @io.swagger.annotations.ApiModelProperty(value = "核销门店code", name = "核销门店code", required = false,example = "")
  private String verifyedStoreCode;
  
  @io.swagger.annotations.ApiModelProperty(value = "核销人(导购code)", name = "导购code", required = false,example = "")
  private String verifyedUser;
  

	public String getVerifyedUser() {
		return verifyedUser;
	}

	public void setVerifyedUser(String verifyedUser) {
		this.verifyedUser = verifyedUser;
	}

	public String getVerifyedStoreCode() {
		return verifyedStoreCode;
	}

	public void setVerifyedStoreCode(String verifyedStoreCode) {
		this.verifyedStoreCode = verifyedStoreCode;
	}

  
  
  public Long getSysCompanyId() {
	return sysCompanyId;
}

public void setSysCompanyId(Long sysCompanyId) {
	this.sysCompanyId = sysCompanyId;
}

public String getStaffCode() {
    return staffCode;
  }

  public void setStaffCode(String staffCode) {
    this.staffCode = staffCode;
  }


  public Byte getUseFrom() {
    return useFrom;
  }

  public void setUseFrom(Byte useFrom) {
    this.useFrom = useFrom;
  }

  public String getCouponCode() {
    return couponCode;
  }

  public void setCouponCode(String couponCode) {
    this.couponCode = couponCode;
  }

  public String getDescription() {
    return description;
  }

  public void setDescription(String description) {
    this.description = description;
  }

  public String getBusinessCode() {
    return businessCode;
  }

  public void setBusinessCode(String businessCode) {
    this.businessCode = businessCode;
  }

  public Long getSysBrandId() {
    return sysBrandId;
  }

  public void setSysBrandId(Long sysBrandId) {
    this.sysBrandId = sysBrandId;
  }

  public String getUseStoreCode() {
    return useStoreCode;
  }

  public void setUseStoreCode(String useStoreCode) {
    this.useStoreCode = useStoreCode;
  }

  public String getUseStoreId() {
    return useStoreId;
  }

  public void setUseStoreId(String useStoreId) {
    this.useStoreId = useStoreId;
  }

  public Integer getIsMember() {
    return isMember;
  }

  public void setIsMember(Integer isMember) {
    this.isMember = isMember;
  }

  public BigDecimal getProfitMoney() {
    return profitMoney;
  }

  public void setProfitMoney(BigDecimal profitMoney) {
    this.profitMoney = profitMoney;
  }

  public BigDecimal getDiscountMoney() {
    return discountMoney;
  }

  public void setDiscountMoney(BigDecimal discountMoney) {
    this.discountMoney = discountMoney;
  }

  public String getUseTime() {
    return useTime;
  }

  public void setUseTime(String useTime) {
    this.useTime = useTime;
  }
}
